==> config-api-0.4.8-sources.jar: org/wildfly/swarm/config/undertow/servlet_container/JSPSetting.java <==
package org.wildfly.swarm.config.undertow.servlet_container;

import org.wildfly.swarm.config.runtime.Address;
import java.util.HashMap;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.Implicit;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;

/**
 * JSP container configuration.
 */
@Address("/subsystem=undertow/servlet-container=*/setting=jsp")
@ResourceType("setting")
@Implicit
public class JSPSetting<T extends JSPSetting<T>> extends HashMap {

	private String key;
	private PropertyChangeSupport pcs;
	private Integer checkInterval;
	private Boolean development;
	private Boolean disabled;
	private Boolean displaySourceFragment;
	private Boolean dumpSmap;
	private Boolean errorOnUseBeanInvalidClassAttribute;
	private Boolean generateStringsAsCharArrays;
	private String javaEncoding;
	private Boolean keepGenerated;
	private Boolean mappedFile;
	private Integer modificationTestInterval;
	private Boolean optimizeScriptlets;
	private Boolean recompileOnFail;
	private String scratchDir;
	private Boolean smap;
	private String sourceVm;
	private Boolean tagPooling;
	private String targetVm;
	private Boolean trimSpaces;
	private Boolean xPoweredBy;

	public JSPSetting() {
		super();
		this.key = "jsp";
		this.pcs = new PropertyChangeSupport(this);
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(
			java.beans.PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	/**
	 * Check interval for JSP updates using a background thread.
	 */
	@ModelNodeBinding(detypedName = "check-interval")
	public Integer checkInterval() {
		return this.checkInterval;
	}

	/**
	 * Check interval for JSP updates using a background thread.
	 */
	@SuppressWarnings("unchecked")
	public T checkInterval(java.lang.Integer value) {
		Object oldValue = this.checkInterval;
		this.checkInterval = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("checkInterval", oldValue, value);
		return (T) this;
	}

	/**
	 * Enable Development mode which enables reloading JSP on-the-fly
	 */
	@ModelNodeBinding(detypedName = "development")
	public Boolean development() {
		return this.development;
	}

	/**
	 * Enable Development mode which enables reloading JSP on-the-fly
	 */
	@SuppressWarnings("unchecked")
	public T development(java.lang.Boolean value) {
		Object oldValue = this.development;
		this.development = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("development", oldValue, value);
		return (T) this;
	}

	/**
	 * Enable the JSP container.
	 */
	@ModelNodeBinding(detypedName = "disabled")
	public Boolean disabled() {
		return this.disabled;
	}

	/**
	 * Enable the JSP container.
	 */
	@SuppressWarnings("unchecked")
	public T disabled(java.lang.Boolean value) {
		Object oldValue = this.disabled;
		this.disabled = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("disabled", oldValue, value);
		return (T) this;
	}

	/**
	 * When a runtime error occurs, attempts to display corresponding JSP source
	 * fragment
	 */
	@ModelNodeBinding(detypedName = "display-source-fragment")
	public Boolean displaySourceFragment() {
		return this.displaySourceFragment;
	}

	/**
	 * When a runtime error occurs, attempts to display corresponding JSP source
	 * fragment
	 */
	@SuppressWarnings("unchecked")
	public T displaySourceFragment(java.lang.Boolean value) {
		Object oldValue = this.displaySourceFragment;
		this.displaySourceFragment = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("displaySourceFragment", oldValue,
					value);
		return (T) this;
	}

	/**
	 * Write SMAP data to a file.
	 */
	@ModelNodeBinding(detypedName = "dump-smap")
	public Boolean dumpSmap() {
		return this.dumpSmap;
	}

	/**
	 * Write SMAP data to a file.
	 */
	@SuppressWarnings("unchecked")
	public T dumpSmap(java.lang.Boolean value) {
		Object oldValue = this.dumpSmap;
		this.dumpSmap = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("dumpSmap", oldValue, value);
		return (T) this;
	}

	/**
	 * Enable errors when using a bad class in useBean.
	 */
	@ModelNodeBinding(detypedName = "error-on-use-bean-invalid-class-attribute")
	public Boolean errorOnUseBeanInvalidClassAttribute() {
		return this.errorOnUseBeanInvalidClassAttribute;
	}

	/**
	 * Enable errors when using a bad class in useBean.
	 */
	@SuppressWarnings("unchecked")
	public T errorOnUseBeanInvalidClassAttribute(java.lang.Boolean value) {
		Object oldValue = this.errorOnUseBeanInvalidClassAttribute;
		this.errorOnUseBeanInvalidClassAttribute = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("errorOnUseBeanInvalidClassAttribute",
					oldValue, value);
		return (T) this;
	}

	/**
	 * Generate String constants as char arrays.
	 */
	@ModelNodeBinding(detypedName = "generate-strings-as-char-arrays")
	public Boolean generateStringsAsCharArrays() {
		return this.generateStringsAsCharArrays;
	}

	/**
	 * Generate String constants as char arrays.
	 */
	@SuppressWarnings("unchecked")
	public T generateStringsAsCharArrays(java.lang.Boolean value) {
		Object oldValue = this.generateStringsAsCharArrays;
		this.generateStringsAsCharArrays = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("generateStringsAsCharArrays",
					oldValue, value);
		return (T) this;
	}

	/**
	 * Specify the encoding used for Java sources.
	 */
	@ModelNodeBinding(detypedName = "java-encoding")
	public String javaEncoding() {
		return this.javaEncoding;
	}

	/**
	 * Specify the encoding used for Java sources.
	 */
	@SuppressWarnings("unchecked")
	public T javaEncoding(java.lang.String value) {
		Object oldValue = this.javaEncoding;
		this.javaEncoding = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("javaEncoding", oldValue, value);
		return (T) this;
	}

	/**
	 * Keep the generated Servlets.
	 */
	@ModelNodeBinding(detypedName = "keep-generated")
	public Boolean keepGenerated() {
		return this.keepGenerated;
	}

	/**
	 * Keep the generated Servlets.
	 */
	@SuppressWarnings("unchecked")
	public T keepGenerated(java.lang.Boolean value) {
		Object oldValue = this.keepGenerated;
		this.keepGenerated = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("keepGenerated", oldValue, value);
		return (T) this;
	}

	/**
	 * Map to the JSP source.
	 */
	@ModelNodeBinding(detypedName = "mapped-file")
	public Boolean mappedFile() {
		return this.mappedFile;
	}

	/**
	 * Map to the JSP source.
	 */
	@SuppressWarnings("unchecked")
	public T mappedFile(java.lang.Boolean value) {
		Object oldValue = this.mappedFile;
		this.mappedFile = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("mappedFile", oldValue, value);
		return (T) this;
	}

	/**
	 * Minimum amount of time between two tests for updates, in seconds.
	 */
	@ModelNodeBinding(detypedName = "modification-test-interval")
	public Integer modificationTestInterval() {
		return this.modificationTestInterval;
	}

	/**
	 * Minimum amount of time between two tests for updates, in seconds.
	 */
	@SuppressWarnings("unchecked")
	public T modificationTestInterval(java.lang.Integer value) {
		Object oldValue = this.modificationTestInterval;
		this.modificationTestInterval = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("modificationTestInterval", oldValue,
					value);
		return (T) this;
	}

	/**
	 * If JSP scriptlets should be optimised to remove string concatenation
	 */
	@ModelNodeBinding(detypedName = "optimize-scriptlets")
	public Boolean optimizeScriptlets() {
		return this.optimizeScriptlets;
	}

	/**
	 * If JSP scriptlets should be optimised to remove string concatenation
	 */
	@SuppressWarnings("unchecked")
	public T optimizeScriptlets(java.lang.Boolean value) {
		Object oldValue = this.optimizeScriptlets;
		this.optimizeScriptlets = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("optimizeScriptlets", oldValue, value);
		return (T) this;
	}

	/**
	 * Retry failed JSP compilations on each request.
	 */
	@ModelNodeBinding(detypedName = "recompile-on-fail")
	public Boolean recompileOnFail() {
		return this.recompileOnFail;
	}

	/**
	 * Retry failed JSP compilations on each request.
	 */
	@SuppressWarnings("unchecked")
	public T recompileOnFail(java.lang.Boolean value) {
		Object oldValue = this.recompileOnFail;
		this.recompileOnFail = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("recompileOnFail", oldValue, value);
		return (T) this;
	}

	/**
	 * Specify a different work directory.
	 */
	@ModelNodeBinding(detypedName = "scratch-dir")
	public String scratchDir() {
		return this.scratchDir;
	}

	/**
	 * Specify a different work directory.
	 */
	@SuppressWarnings("unchecked")
	public T scratchDir(java.lang.String value) {
		Object oldValue = this.scratchDir;
		this.scratchDir = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("scratchDir", oldValue, value);
		return (T) this;
	}

	/**
	 * Enable SMAP.
	 */
	@ModelNodeBinding(detypedName = "smap")
	public Boolean smap() {
		return this.smap;
	}

	/**
	 * Enable SMAP.
	 */
	@SuppressWarnings("unchecked")
	public T smap(java.lang.Boolean value) {
		Object oldValue = this.smap;
		this.smap = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("smap", oldValue, value);
		return (T) this;
	}

	/**
	 * Source VM level for compilation.
	 */
	@ModelNodeBinding(detypedName = "source-vm")
	public String sourceVm() {
		return this.sourceVm;
	}

	/**
	 * Source VM level for compilation.
	 */
	@SuppressWarnings("unchecked")
	public T sourceVm(java.lang.String value) {
		Object oldValue = this.sourceVm;
		this.sourceVm = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("sourceVm", oldValue, value);
		return (T) this;
	}

	/**
	 * Enable tag pooling.
	 */
	@ModelNodeBinding(detypedName = "tag-pooling")
	public Boolean tagPooling() {
		return this.tagPooling;
	}

	/**
	 * Enable tag pooling.
	 */
	@SuppressWarnings("unchecked")
	public T tagPooling(java.lang.Boolean value) {
		Object oldValue = this.tagPooling;
		this.tagPooling = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("tagPooling", oldValue, value);
		return (T) this;
	}

	/**
	 * Target VM level for compilation.
	 */
	@ModelNodeBinding(detypedName = "target-vm")
	public String targetVm() {
		return this.targetVm;
	}

	/**
	 * Target VM level for compilation.
	 */
	@SuppressWarnings("unchecked")
	public T targetVm(java.lang.String value) {
		Object oldValue = this.targetVm;
		this.targetVm = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("targetVm", oldValue, value);
		return (T) this;
	}

	/**
	 * Trim some spaces from the generated Servlet.
	 */
	@ModelNodeBinding(detypedName = "trim-spaces")
	public Boolean trimSpaces() {
		return this.trimSpaces;
	}

	/**
	 * Trim some spaces from the generated Servlet.
	 */
	@SuppressWarnings("unchecked")
	public T trimSpaces(java.lang.Boolean value) {
		Object oldValue = this.trimSpaces;
		this.trimSpaces = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("trimSpaces", oldValue, value);
		return (T) this;
	}

	/**
	 * Enable advertising the JSP engine in x-powered-by.
	 */
	@ModelNodeBinding(detypedName = "x-powered-by")
	public Boolean xPoweredBy() {
		return this.xPoweredBy;
	}

	/**
	 * Enable advertising the JSP engine in x-powered-by.
	 */
	@SuppressWarnings("unchecked")
	public T xPoweredBy(java.lang.Boolean value) {
		Object oldValue = this.xPoweredBy;
		this.xPoweredBy = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("xPoweredBy", oldValue, value);
		return (T) this;
	}
}

==> config-api-0.5.3-sources.jar: org/wildfly/swarm/config/undertow/servlet_container/JSPSetting.java <==
package org.wildfly.swarm.config.undertow.servlet_container;

import org.wildfly.swarm.config.runtime.Address;
import java.util.HashMap;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.Implicit;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;

/**
 * JSP container configuration.
 */
@Address("/subsystem=undertow/servlet-container=*/setting=jsp")
@ResourceType("setting")
@Implicit
public class JSPSetting<T extends JSPSetting<T>> extends HashMap
		implements
			org.wildfly.swarm.config.runtime.Keyed {

	private String key;
	private PropertyChangeSupport pcs;
	private Integer checkInterval;
	private Boolean development;
	private Boolean disabled;
	private Boolean displaySourceFragment;
	private Boolean dumpSmap;
	private Boolean errorOnUseBeanInvalidClassAttribute;
	private Boolean generateStringsAsCharArrays;
	private String javaEncoding;
	private Boolean keepGenerated;
	private Boolean mappedFile;
	private Integer modificationTestInterval;
	private Boolean optimizeScriptlets;
	private Boolean recompileOnFail;
	private String scratchDir;
	private Boolean smap;
	private String sourceVm;
	private Boolean tagPooling;
	private String targetVm;
	private Boolean trimSpaces;
	private Boolean xPoweredBy;

	public JSPSetting() {
		super();
		this.key = "jsp";
		this.pcs = new PropertyChangeSupport(this);
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(
			java.beans.PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	/**
	 * Check interval for JSP updates using a background thread.
	 */
	@ModelNodeBinding(detypedName = "check-interval")
	public Integer checkInterval() {
		return this.checkInterval;
	}

	/**
	 * Check interval for JSP updates using a background thread.
	 */
	@SuppressWarnings("unchecked")
	public T checkInterval(java.lang.Integer value) {
		Object oldValue = this.checkInterval;
		this.checkInterval = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("checkInterval", oldValue, value);
		return (T) this;
	}

	/**
	 * Enable Development mode which enables reloading JSP on-the-fly
	 */
	@ModelNodeBinding(detypedName = "development")
	public Boolean development() {
		return this.development;
	}

	/**
	 * Enable Development mode which enables reloading JSP on-the-fly
	 */
	@SuppressWarnings("unchecked")
	public T development(java.lang.Boolean value) {
		Object oldValue = this.development;
		this.development = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("development", oldValue, value);
		return (T) this;
	}

	/**
	 * Enable the JSP container.
	 */
	@ModelNodeBinding(detypedName = "disabled")
	public Boolean disabled() {
		return this.disabled;
	}

	/**
	 * Enable the JSP container.
	 */
	@SuppressWarnings("unchecked")
	public T disabled(java.lang.Boolean value) {
		Object oldValue = this.disabled;
		this.disabled = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("disabled", oldValue, value);
		return (T) this;
	}

	/**
	 * When a runtime error occurs, attempts to display corresponding JSP source
	 * fragment
	 */
	@ModelNodeBinding(detypedName = "display-source-fragment")
	public Boolean displaySourceFragment() {
		return this.displaySourceFragment;
	}

	/**
	 * When a runtime error occurs, attempts to display corresponding JSP source
	 * fragment
	 */
	@SuppressWarnings("unchecked")
	public T displaySourceFragment(java.lang.Boolean value) {
		Object oldValue = this.displaySourceFragment;
		this.displaySourceFragment = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("displaySourceFragment", oldValue,
					value);
		return (T) this;
	}

	/**
	 * Write SMAP data to a file.
	 */
	@ModelNodeBinding(detypedName = "dump-smap")
	public Boolean dumpSmap() {
		return this.dumpSmap;
	}

	/**
	 * Write SMAP data to a file.
	 */
	@SuppressWarnings("unchecked")
	public T dumpSmap(java.lang.Boolean value) {
		Object oldValue = this.dumpSmap;
		this.dumpSmap = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("dumpSmap", oldValue, value);
		return (T) this;
	}

	/**
	 * Enable errors when using a bad class in useBean.
	 */
	@ModelNodeBinding(detypedName = "error-on-use-bean-invalid-class-attribute")
	public Boolean errorOnUseBeanInvalidClassAttribute() {
		return this.errorOnUseBeanInvalidClassAttribute;
	}

	/**
	 * Enable errors when using a bad class in useBean.
	 */
	@SuppressWarnings("unchecked")
	public T errorOnUseBeanInvalidClassAttribute(java.lang.Boolean value) {
		Object oldValue = this.errorOnUseBeanInvalidClassAttribute;
		this.errorOnUseBeanInvalidClassAttribute = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("errorOnUseBeanInvalidClassAttribute",
					oldValue, value);
		return (T) this;
	}

	/**
	 * Generate String constants as char arrays.
	 */
	@ModelNodeBinding(detypedName = "generate-strings-as-char-arrays")
	public Boolean generateStringsAsCharArrays() {
		return this.generateStringsAsCharArrays;
	}

	/**
	 * Generate String constants as char arrays.
	 */
	@SuppressWarnings("unchecked")
	public T generateStringsAsCharArrays(java.lang.Boolean value) {
		Object oldValue = this.generateStringsAsCharArrays;
		this.generateStringsAsCharArrays = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("generateStringsAsCharArrays",
					oldValue, value);
		return (T) this;
	}

	/**
	 * Specify the encoding used for Java sources.
	 */
	@ModelNodeBinding(detypedName = "java-encoding")
	public String javaEncoding() {
		return this.javaEncoding;
	}

	/**
	 * Specify the encoding used for Java sources.
	 */
	@SuppressWarnings("unchecked")
	public T javaEncoding(java.lang.String value) {
		Object oldValue = this.javaEncoding;
		this.javaEncoding = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("javaEncoding", oldValue, value);
		return (T) this;
	}

	/**
	 * Keep the generated Servlets.
	 */
	@ModelNodeBinding(detypedName = "keep-generated")
	public Boolean keepGenerated() {
		return this.keepGenerated;
	}

	/**
	 * Keep the generated Servlets.
	 */
	@SuppressWarnings("unchecked")
	public T keepGenerated(java.lang.Boolean value) {
		Object oldValue = this.keepGenerated;
		this.keepGenerated = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("keepGenerated", oldValue, value);
		return (T) this;
	}

	/**
	 * Map to the JSP source.
	 */
	@ModelNodeBinding(detypedName = "mapped-file")
	public Boolean mappedFile() {
		return this.mappedFile;
	}

	/**
	 * Map to the JSP source.
	 */
	@SuppressWarnings("unchecked")
	public T mappedFile(java.lang.Boolean value) {
		Object oldValue = this.mappedFile;
		this.mappedFile = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("mappedFile", oldValue, value);
		return (T) this;
	}

	/**
	 * Minimum amount of time between two tests for updates, in seconds.
	 */
	@ModelNodeBinding(detypedName = "modification-test-interval")
	public Integer modificationTestInterval() {
		return this.modificationTestInterval;
	}

	/**
	 * Minimum amount of time between two tests for updates, in seconds.
	 */
	@SuppressWarnings("unchecked")
	public T modificationTestInterval(java.lang.Integer value) {
		Object oldValue = this.modificationTestInterval;
		this.modificationTestInterval = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("modificationTestInterval", oldValue,
					value);
		return (T) this;
	}

	/**
	 * If JSP scriptlets should be optimised to remove string concatenation
	 */
	@ModelNodeBinding(detypedName = "optimize-scriptlets")
	public Boolean optimizeScriptlets() {
		return this.optimizeScriptlets;
	}

	/**
	 * If JSP scriptlets should be optimised to remove string concatenation
	 */
	@SuppressWarnings("unchecked")
	public T optimizeScriptlets(java.lang.Boolean value) {
		Object oldValue = this.optimizeScriptlets;
		this.optimizeScriptlets = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("optimizeScriptlets", oldValue, value);
		return (T) this;
	}

	/**
	 * Retry failed JSP compilations on each request.
	 */
	@ModelNodeBinding(detypedName = "recompile-on-fail")
	public Boolean recompileOnFail() {
		return this.recompileOnFail;
	}

	/**
	 * Retry failed JSP compilations on each request.
	 */
	@SuppressWarnings("unchecked")
	public T recompileOnFail(java.lang.Boolean value) {
		Object oldValue = this.recompileOnFail;
		this.recompileOnFail = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("recompileOnFail", oldValue, value);
		return (T) this;
	}

	/**
	 * Specify a different work directory.
	 */
	@ModelNodeBinding(detypedName = "scratch-dir")
	public String scratchDir() {
		return this.scratchDir;
	}

	/**
	 * Specify a different work directory.
	 */
	@SuppressWarnings("unchecked")
	public T scratchDir(java.lang.String value) {
		Object oldValue = this.scratchDir;
		this.scratchDir = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("scratchDir", oldValue, value);
		return (T) this;
	}

	/**
	 * Enable SMAP.
	 */
	@ModelNodeBinding(detypedName = "smap")
	public Boolean smap() {
		return this.smap;
	}

	/**
	 * Enable SMAP.
	 */
	@SuppressWarnings("unchecked")
	public T smap(java.lang.Boolean value) {
		Object oldValue = this.smap;
		this.smap = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("smap", oldValue, value);
		return (T) this;
	}

	/**
	 * Source VM level for compilation.
	 */
	@ModelNodeBinding(detypedName = "source-vm")
	public String sourceVm() {
		return this.sourceVm;
	}

	/**
	 * Source VM level for compilation.
	 */
	@SuppressWarnings("unchecked")
	public T sourceVm(java.lang.String value) {
		Object oldValue = this.sourceVm;
		this.sourceVm = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("sourceVm", oldValue, value);
		return (T) this;
	}

	/**
	 * Enable tag pooling.
	 */
	@ModelNodeBinding(detypedName = "tag-pooling")
	public Boolean tagPooling() {
		return this.tagPooling;
	}

	/**
	 * Enable tag pooling.
	 */
	@SuppressWarnings("unchecked")
	public T tagPooling(java.lang.Boolean value) {
		Object oldValue = this.tagPooling;
		this.tagPooling = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("tagPooling", oldValue, value);
		return (T) this;
	}

	/**
	 * Target VM level for compilation.
	 */
	@ModelNodeBinding(detypedName = "target-vm")
	public String targetVm() {
		return this.targetVm;
	}

	/**
	 * Target VM level for compilation.
	 */
	@SuppressWarnings("unchecked")
	public T targetVm(java.lang.String value) {
		Object oldValue = this.targetVm;
		this.targetVm = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("targetVm", oldValue, value);
		return (T) this;
	}

	/**
	 * Trim some spaces from the generated Servlet.
	 */
	@ModelNodeBinding(detypedName = "trim-spaces")
	public Boolean trimSpaces() {
		return this.trimSpaces;
	}

	/**
	 * Trim some spaces from the generated Servlet.
	 */
	@SuppressWarnings("unchecked")
	public T trimSpaces(java.lang.Boolean value) {
		Object oldValue = this.trimSpaces;
		this.trimSpaces = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("trimSpaces", oldValue, value);
		return (T) this;
	}

	/**
	 * Enable advertising the JSP engine in x-powered-by.
	 */
	@ModelNodeBinding(detypedName = "x-powered-by")
	public Boolean xPoweredBy() {
		return this.xPoweredBy;
	}

	/**
	 * Enable advertising the JSP engine in x-powered-by.
	 */
	@SuppressWarnings("unchecked")
	public T xPoweredBy(java.lang.Boolean value) {
		Object oldValue = this.xPoweredBy;
		this.xPoweredBy = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("xPoweredBy", oldValue, value);
		return (T) this;
	}
}
